/// <reference types="node" />
import Context from './Context';
import { ConsoleMessageType, Page, Viewport } from 'puppeteer';
import { diff_match_patch } from 'diff-match-patch';
import { IExpectation } from './Expects';
export declare const DMP: diff_match_patch;
export type IPageInclude = {
    url: string;
    method: string;
    resourceType: string;
    content: Buffer;
    headers: Record<string, string>;
};
export type ISnapshot = {
    type: 'snapshot';
    html?: any;
    data?: any;
    version: number;
    url: any;
    viewport: Viewport | null;
    isJavascriptEnabled: boolean;
    includes?: IPageInclude[];
};
export type ICommandError = {
    type: string;
    specific?: string;
    error?: Error;
    expectation?: IExpectation;
    time: number;
};
export type ICommand = {
    id: string;
    type: 'command';
    snapshots: {
        before: ISnapshot | undefined;
        after: ISnapshot | undefined;
    };
    errors: ICommandError[];
    context: {};
    func: string;
    args: string[];
    on: {
        type: string;
        path: [[string, number][] | string][];
    };
    time: {
        started: number;
        elapsed: number;
        took?: number;
        finished?: number;
    };
};
export type ILogLocation = {
    url?: string;
    lineNumber?: number;
    columnNumber?: number;
};
export type ILog = {
    type: 'log';
    context: {};
    time: number;
    messageType: ConsoleMessageType;
    args: any[];
    location: ILogLocation;
    text: string;
    stackTrace: ILogLocation[];
};
export type IResponse = {
    type: 'response';
    context: {};
    time: number;
    isNavigationRequest: boolean;
    url: string;
    resourceType: string;
    method: string;
    headers: {
        [key: string]: string;
    };
    content: Uint8Array;
};
declare enum SnapshotState {
    BEFORE = 0,
    AFTER = 1
}
declare class SnapshotHandler {
    private cache;
    pushToCache(context: any, item: any, { broadcast }?: {
        broadcast: boolean;
    }): void;
    log(...msg: any[]): void;
    createBefore(context: Context, page: Page, command: ICommand | undefined): Promise<void>;
    createAfter(context: Context, page: Page, command: ICommand | undefined): Promise<void>;
    error(param: Context, page: Page, command: ICommand | undefined, error: ICommandError): void;
    broadcast(object: any): void;
    resolveSnapshotBacktrack(commands: any, index: any, snapshotState?: SnapshotState | null): any;
    makeSnapshot(context: Context, page: Page, snapshotState: SnapshotState): Promise<ISnapshot | undefined>;
    makeSnapshotV2(context: Context, page: Page, snapshotState: SnapshotState): Promise<ISnapshot | undefined>;
    createPageSnapshot(page: Page, { cacheAllStyleTags }?: {
        cacheAllStyleTags?: boolean | undefined;
    }): Promise<any>;
    getAllCachedItems(): never[];
    getAllCachedItemsFrom(context: any): never[];
    hasCachedItems(): boolean;
}
declare const Snapshots: SnapshotHandler;
export default Snapshots;
